import codecs
from ruamel.yaml import YAML


requirements = {}
meta = {}
yaml = YAML()


def read_yaml(path):
    """Reads the yaml file and returns the content """
    content = {}
    with codecs.open(path, 'r', encoding='utf8') as stream:
        content = yaml.load(stream)
    return content


def write_yaml(path, content):
    """ Writes the yaml content into the file """
    with codecs.open(path, mode='w', encoding='utf8') as stream:
        yaml.dump(content, stream)

    # Force --- as the first line of the file
    data = ""
    with codecs.open(path, 'r') as original:
        data = original.read()
    with codecs.open(path, 'w') as modified:
        modified.write("---\n" + data)



import os
import unittest
import tempfile

from molecule_wrapper.io import read_yaml, write_yaml

current_dir = os.path.dirname(os.path.realpath(__file__))
fixtures_path = "{}/fixtures".format(current_dir)


def test_load():
    expected = {"foo": "bar"}
    got = read_yaml("{}/test_load.yaml".format(fixtures_path))
    assert expected == got


def test_dump():
    content = read_yaml("{}/test_load.yaml".format(fixtures_path))
    _, filename = tempfile.mkstemp()

    write_yaml(filename, content)

    with open(filename, 'r', encoding='utf-8') as stream:
        content = stream.read()
        assert content == "---\nfoo: bar\n"

    os.remove(filename)



import sys
import os
from .io import read_yaml, write_yaml
from .galaxy import install

# Python 2 compatibility
try:
    FileNotFoundError
except NameError:
    FileNotFoundError = IOError


def load_or_die(file_path):
    try:
        return read_yaml(file_path)
    except FileNotFoundError:
        print("{} file does not exists".format(file_path))
        sys.exit(1)


def main():
    meta_requirements_path = "meta/{}".format("main.yml")
    requirements_path = "requirements.yml"

    requirements = load_or_die(requirements_path)
    meta_requirements = load_or_die(meta_requirements_path)

    if requirements is None:
        print("No dependencies defined inside requirements.yml")
        requirements = []

    if 'dependencies' not in meta_requirements:
        print(
            "Format Error - Ansible Galaxy {} file does not contain main dependencies list".format(meta_requirements_path))
        sys.exit(1)

    print("Appending {} content into {} dependencies".format(
        requirements_path, meta_requirements_path))
    meta_requirements['dependencies'] = requirements
    write_yaml(meta_requirements_path, meta_requirements)

    # Role with no dependencies, successfully exit, no need to run ansible-galaxy install
    if requirements == []:
        sys.exit(0)

    ephemeral_dir = os.getenv("MOLECULE_EPHEMERAL_DIRECTORY")
    debug_mode = os.getenv("MOLECULE_DEBUG") == "True"

    if ephemeral_dir is None:
        print("This tool should be used with molecule. The variable MOLECULE_EPHEMERAL_DIRECTORY is not defined")
        sys.exit(1)

    roles_path = "{}/roles".format(ephemeral_dir)
    install(requirements_path, roles_path, debug_mode)


if __name__ == "__main__":
    main()



import subprocess


def install(requirements_path, roles_path, debug_mode=False):
    command = ["ansible-galaxy", "install", "--role-file",
               requirements_path, "--roles-path", roles_path, "--force"]

    if debug_mode:
        command.append("-vvv")

    subprocess.call(command)
